/*--------------------------------------------------------------------*/
/*                                                                    */
/*  PROGRAM NAME : RDFLAT2006.SAS                                        */
/*  AUTHOR: JAN WHITTON                   DATE: January 18, 1995      */
/*  LANGUAGE/SYSTEM: SAS                                              */
/*                                                                    */
/*  PURPOSE: READS IN THE 2006 FLAT FILE.  WRITES OUT EACH FORM TO    */
/*           SEPARATE SAS DATA SET.  PROGRAM WILL BE SENT TO          */
/*           CUSTOMERS WITH FLAT FILE TOGETHER WITH THE FORMAT FILE.  */
/*                                                                    */
/*  Input file names and paths                                        */
/*     \\NASS-SAS\REPORTS  --> DRIVE NUMBER                                           */
/*     ANALYSIS.FLT --> dataset name of flat file                     */
/*     path1   --> location of NASS flat data input file              */
/*     path2   --> location of NASS SAS output files                  */
/*                                                                    */
/*  SAS OUTPUT FILES WILL BE NAME\\NASS-SAS\REPORTS                                   */
/*     ACCIDENT.SD2 on path1  for the ACCIDENT file                   */
/*     EVENT.SD2 on path1  for the EVENT file                         */
/*     GV.SD2    on path1  for the GENERAL VEHICLE file               */
/*     OA.SD2    on path1  for the OCCUPANT ASSESSMENT file           */
/*     OI.SD2    on path1  for the OCCUPANT INJURY file               */
/*     VE.SD2    on path1  for the VEHICLE EXTERIOR file              */
/*     VI.SD2    on path1  for the VEHICLE INTERIOR file              */
/*                                                                    */
/*   DELETE THE OLD DATASETs TO ALLOW ROOM FOR THE NEW ONEs.          */
/* MODIFICATIONS: JCW 5/22/95 Added new summary forms: TYP_ACC,       */
/*                            VEH_PRO, PERS_PRO, ACC_DESC             */
/*                JCW 7/23/96 Added new variables from pcvina extract */
/*                            to gv form.                             */
/*                JCW 4/29/99 ADDED RABCLASS                          */
/*                JCW 5/02/200 REMOVED RABCLASS */
/**********************************************************************/

OPTIONS ERRORS=0 MTRACE MPRINT SYMBOLGEN;

LIBNAME NASSOUT '\\NASS-SAS\REPORTS\JAN';
FILENAME FLATIN '\\NASS-SAS\REPORTS\NASS\FINAL\2006\ANALYSIS.FLT';

DATA NASSOUT.ACCIDENT(KEEP= AAIS ADMINSS AINJSER AINJURED ALCINV
                            ATREAT CASEID CASENO DAYWEEK DRGINV
                            EVENTS
                            MANCOLL MONTH RATWGT RATWGT_U PSU PSUSTRAT 
                             STRATIF TIME   VEHFORMS VERSION YEAR)
     NASSOUT.EVENT(KEEP= ACCSEQ CASEID CASENO CLASS1 CLASS2 GADEV1 GADEV2
                          OBJCONT PSU STRATIF VEHNUM VERSION RATWGT RATWGT_U)
     NASSOUT.GV(KEEP= ACCSEQDV ACCTYPE ALCTEST ALIGNMNT ANGOTHER ANGTHIS ANTILOCK AOPSVEH
                      BAGDEPFV BAGDEPOV BAREQSP BODYTYPE CARBUR CARGOWGT CASEID CASENO DAYRUNLT
                      CONDTREE CURBWGT DOCTRAJ DRIVDIST DRUGS
                      DRINKING DRIVE DRPRES DRRACE DRZIP DVBASIS
                      DVCONFID DVEST DVLAT DVLONG DVTOTAL ENERGY FOURWHDR
                      FOVERIDE FRTWHLDR FUELCODE IMPACTSP INSPTYPE LANES LGTCOND MAKE MANEUVER
                      MCYCLDS
                      MODEL MODELYR OCCFORMS OCUPANTS
                      OTBDYTYP OTVEHWGT PREEVENT PREILOC PREISTAB PREMOVE
                      PROFILE PSU RATWGT RATWGT_U
                      RELINTER RESTYPE
                      ROLINDIR ROLINLOC ROLINTYP ROLLOBJ ROLLOVER
                      ROOF1 ROOF2 ROOF3 ROVERIDE SERTR
                      SPECOTH SPLIMIT STRATIF SURCOND SURTYPE TOWHITCH
                      TOWPAR TRAFCONT TRCTLFCT TRAVELSP TRAFFLOW TRIPLOC VAIS
                      VEHNO VEHTYPE VEHUSE VEHWGT VERSION VIN VINAMOD VINBT VINO
                      VINJSER VINJURED VINMODYR VINLNGTH VINMAKE VTREAT WEATHER WGTCDTR WHLDRWHL)

     NASSOUT.VE(KEEP=  ACCSEQ1 ACCSEQ2 ALTVEH CASEID CASENO
                       DIRDAMW DOCCDC DOF1 DOF2 DVC1 DVC2 DVC3 DVC4 DVC5 DVC6
                       DVD DVL EXTENT1 EXTENT2 FUELCAP1 FUELCAP2
                       FIRE FIREORIG FUELDAM1 FUELDAM2 FUELLOC1 FUELLOC2
                       FUELTNK1 FUELTNK2 FUELTYP1 FUELTYP2 GAD1 GAD2
                       FUELEAK1 FUELEAK2 FUELGT2 OBJCONT1 OBJCONT2
                       ORIGAVTW PDOF1 PDOF2 PSU SDVC1 SDVC2 SDVC3 SDVC4 SDVC5
                       SDVC6 SDVD SDVL SHL1 SHL2 STRATIF SVL1 SVL2 TDD1 TDD2
                       TOWRES UNDENDW VEHNO VERSION WHEELBAS RATWGT RATWGT_U)
     NASSOUT.VI(KEEP= ADAPTEQ BOLSTDEF CASEID CASENO CDRIR1 CDRIR2 CDRIR3
                      CDRIR4 CDRIR5 CDRIR6 CDRIR7 CDRIR8 CDRIR9 CDRIR10
                      COLUMTYP FAILLF FAILLR FAILRF FAILRR FAILTG GLIMPBL GLIMPLF
                      GLIMPLR GLIMPOTH GLIMPRF GLIMPRR GLIMPRUF GLIMPWS
                      GLOCCBL GLOCCLF GLOCCLR GLOCCOTH GLOCCRF GLOCCRR
                      GLOCCRUF GLOCCWS GLOVOPEN GLPREBL GLPRELF GLPRELR
                      GLPREOTH GLPRERF GLPRERR GLPRERUF GLPREWS GLTYPBL
                      GLTYPLF GLTYPLR GLTYPOTH GLTYPRF GLTYPRR GLTYPRUF
                      GLTYPWS INCOMP1 INCOMP2 INCOMP3 INCOMP4 INCOMP5
                      INCOMP6 INCOMP7 INCOMP8 INCOMP9 INCOMP10 INLOC1
                      INLOC2 INLOC3 INLOC4  INLOC5 INLOC6 INLOC7 INLOC8
                      INLOC9 INLOC10 INMAG1 INMAG2 INMAG3 INMAG4 INMAG5
                      INMAG6 INMAG7 INMAG8  INMAG9 INMAG10  ODOMETER
                      OPENLF OPENLR OPENRF OPENRR OPENTG PANELDAM PASINTEG
                      PSU RATWGT RATWGT_U RDEFLOC RIMDEF STRATIF COLMTELE COLMTILT
                      BOLSTYPE VEHNO VERSION )
     NASSOUT.OA(KEEP= ABELTAVL ABELTYPE ABELTUSE ABLTFAIL ABLTPROP AGE
                      BAGAVAIL BAGAVRPT BAGDEPLY BAGDAMAG BAGEVENT BAGFAIL
                      BAGTYPE BAGTETHR BICARB BLOOD BELTANCH
                      CASEID CASENO CAUSE1 CAUSE2 CAUSE3 BAGCDC CHHARNES CHMAKE
                      CHORIENT CHSHIELD CHTETHER CHTYPE BAGCONOT
                      DEATH DVBAG EJCTAREA EJCTMED EJECTION ENTRAP
                      BAGFLDAM BAGFLOPN GLASGOW HEADREST
                      HEIGHT HOSPSTAY INJNUM INJSEV ISS BAGMAINT MAIS MANAVAIL
                      MANFAIL MANPROPR MANUSE MEDFACIL MEDSTA EYEWEAR OCCMOBIL OCCNO
                      BAGAVOTH BAGDEPOT PARUSE BELTSOU POSTURE PREVACC
                      PSU ROLE SEATPERF SEATPOS SEATTYPE SEX BAGDAMSO STBACINC
                      STORIENT STRATIF SEATRACK TREATMNT BAGVENTS VERSION
                      WEIGHT WORKDAYS RATWGT RATWGT_U VEHNO )
     NASSOUT.OI(KEEP= AIS ASPECT90 BODYREG CASEID CASENO DIRINJ INJLEVEL INJNO INJSOU
                      INTRUNO LESION OCCNO PSU RATWGT RATWGT_U REGION90 SOUCON SOUDAT STRATIF
                      STRUSPEC STRUTYPE SYSORG VEHNO VERSION )



     NASSOUT.TYP_ACC(KEEP=CASEID STRATIF CASENO LINENO PSU TEXT66 VERSION)

     NASSOUT.ACC_DESC(KEEP=CASEID STRATIF CASENO LINENO PSU TEXT71 VERSION)

     NASSOUT.PERS_PRO(KEEP=CASEID CASENO LINENO PSU TEXT91 VERSION STRATIF)

     NASSOUT.VEH_PRO(KEEP=CASEID CASENO LINENO PSU TEXT81 VERSION STRATIF);

     LENGTH DEFAULT = 3;
     LENGTH CURBWGT 4;
     LENGTH DRZIP 4;
     LENGTH ENERGY 4;
     LENGTH VINMAKE $5;
     LENGTH VEHWGT 4;
     LENGTH MODELYR 4;
     LENGTH VINMODYR 4;
     LENGTH TIME 4;
     LENGTH TEXT66 $80;
     LENGTH TEXT71 $80;
     LENGTH TEXT81 $80;
     LENGTH TEXT91 $80;
     LENGTH MCYCLDS 4;
     LENGTH VERSION $5;
     LENGTH WHEELBAS 8;
     LENGTH RATWGT 6;
	 LENGTH RATWGT_U 6;
     INFILE FLATIN LRECL=150;

/**********************************************************************/
/*                             ALL FORMS                              */
/**********************************************************************/

 INPUT @ 1   PSU         2.
       @ 3   CASENO      3.
       @ 6   STRATIF    $1.
       @ 7   CASEKEY4    1.
       @ 8   CASEKEY5    1.
       @ 9   VERSION     $2. @;
       CASEID = (PUT(CASENO,3.)||STRATIF);
/**********************************************************************/
/*                         ACCIDENT FORM                              */
/**********************************************************************/
 LABEL AAIS      =  'MAXIMUM KNOWN AIS IN ACCIDENT'
       ADMINSS   =  'ADMINISTRATIVE USE'
       AINJSER   =  'NUMBER OF SERIOUSLY INJURED OCCUPANTS'
       AINJURED  =  'TOTAL NUMBER OF INJURED OCCUPANTS'
       ALCINV    =  'ALCOHOL INVOLVED IN ACCIDENT'
       ATREAT    =  'MAXIMUM TREATMENT IN ACCIDENT'
       CASEID    =  'CASE NUMBER - STRATUM'
       CASENO    =  'CASE SEQUENCE NUMBER'
       DAYWEEK   =  'DAY OF WEEK OF ACCIDENT'
       DRGINV    =  'DRUG INVOLVED'
       EVENTS    =  'NUMBER OF RECORDED EVENTS IN ACCIDENT'
/*       FIRESTDY  =  'IMPACT FIRES'*/
       MANCOLL   =  'MANNER OF COLLISION'
       MONTH     =  'MONTH OF ACCIDENT'
       RATWGT    =  'NATIONAL INFLATION FACTOR'
	   RATWGT_U  =  'NATIONAL INGLATION FACTOR UNTRIMMED'
       PSU       =  'PRIMARY SAMPLING UNIT NUMBER'
       PSUSTRAT  =  'PRIMARY SAMPLING UNIT STRATIFICATION'
/*       AOPSS     =  'ADVANCED OCCUPANT PROTECTION SPECIAL STUDY'*/
/*       RATWGT    =  'RATIO INFLATION FACTOR'*/
       STRATIF   =  'CASE STRATUM'
       TIME      =  'TIME OF ACCIDENT'
       VEHFORMS  =  'NUMBER GENERAL VEHICLE FORMS SUBMITTED'
       VERSION   =  'VERSION NUMBER'
       YEAR      =  'YEAR OF ACCIDENT';
IF (CASEKEY4 = 1 AND CASEKEY5 = 1) THEN DO;

 INPUT @ 11  VEHFORMS   2.
       @ 13  MONTH      2.   /*COLUMNS 15-16 INTENTIONALLY LEFT BLANK*/
       @ 17  YEAR       4.
       @ 21  TIME       4.
       @ 25  ADMINSS    1.
       /* @26 was pedstudy*/
       /*@ 27  FIRESTDY   1.*/
       /* @28 TRKURIDE   1.*/  /*no longer used*/
       /* @ 29  AOPSS      1.*/
       /* @ 30 was runoffrd*/
       @ 31  EVENTS     2.
       @ 33  ATREAT     1.
       @ 34  AAIS       1.
       @ 35  AINJSER    2.
       @ 37  AINJURED   2.
       @ 39  ALCINV     1.
       @ 40  DAYWEEK    2.
       @ 58  RIFX        8.
       @ 66  DRGINV      1.
       @ 67  MANCOLL     1.
       @ 68  PSUSTRAT    2.
	   @ 70  RUIFX       8.
       ;

RATWGT = (RIFX/1000);
RATWGT_U = (RUIFX/1000);

 ARRAY ONEAC AAIS ALCINV ATREAT DRGINV MANCOLL;

 ARRAY TWOAC AINJSER AINJURED DAYWEEK;

 ARRAY FOURAC TIME;

 DO OVER ONEAC;
    IF ONEAC = 9 THEN ONEAC = .U;
    IF ONEAC = . THEN ONEAC = .N;
 END;

 DO OVER TWOAC;
    IF TWOAC = 99 THEN TWOAC = .U;
    IF TWOAC = . THEN TWOAC = .N;
 END;

 DO OVER FOURAC;
    IF FOURAC = 9999 THEN FOURAC = .U;
 END;

 RETAIN PSUSTRAT;
 RETAIN RATWGT RATWGT_U;

 OUTPUT NASSOUT.ACCIDENT;

 END;

/**********************************************************************/
/*                            EVENT FORM                              */
/**********************************************************************/

ELSE IF (CASEKEY4 = 1 AND CASEKEY5 = 2) THEN DO;

LABEL ACCSEQ  =  'ACCIDENT EVENT SEQUENCE NUMBER'
      CASEID  =  'CASE NUMBER - STRATUM'
      CASENO  =  'CASE SEQUENCE NUMBER'
      CLASS1  =  'CLASS OF FIRST VEHICLE'
      CLASS2  =  'CLASS OF OTHER VEHICLE'
      GADEV1  =  'GENERAL AREA OF DAMAGE FIRST VEHICLE'
      GADEV2  =  'GENERAL AREA OF DAMAGE OTHER VEHICLE'
      OBJCONT =  'OTHER VEHICLE NUMBER OR OBJECT CONTACTED'
      PSU     =  'PRIMARY SAMPLING UNIT NUMBER'
      STRATIF =  'CASE STRATUM'
      VEHNUM  =  'VEHICLE NUMBER'
      VERSION =  'VERSION NUMBER';

   INPUT @11   ACCSEQ     2.  /*ALIAS CASEKEY2*/
         @13   VEHNUM     2.
         @15   CLASS1     2.
         @17   GADEV1     $1.
         @18   OBJCONT    2.
         @20   CLASS2     2.
         @22   GADEV2     $1.
                          ;

ARRAY TWOEV CLASS1 CLASS2 OBJCONT VEHNUM;

DO OVER TWOEV;
   IF TWOEV = 99 THEN TWOEV = .U;
END;

OUTPUT NASSOUT.EVENT;

END;

/**********************************************************************/
/*                              GV FORM                               */
/**********************************************************************/

ELSE IF (CASEKEY4 = 2 AND CASEKEY5 = 1) THEN DO;
LABEL  ACCSEQDV  = 'ACCIDENT SEQUENCE NO FOR HIGHEST DELTA V'
       ACCTYPE   = 'ACCIDENT TYPE'
       ALCTEST   = 'ALCOHOL TEST RESULT FOR DRIVER'
       ALIGNMNT  = 'ROADWAY ALIGNMENT'
       ANGOTHER  = 'HEADING ANGLE FOR OTHER VEHICLE'
       ANGTHIS   = 'HEADING ANGLE FOR THIS VEHICLE'
       ANTILOCK  = 'ANTILOCK BRAKES'
       AOPSVEH   = 'AOPS VEHICLE'
       WEATHER   = 'ATMOSPHERIC CONDITIONS'
       BAGDEPFV  = 'AIR BAG DEPLOYMENT, FIRST SEAT FRONTAL'
       BAGDEPOV  = 'AIR BAG DEPLOYMENT, OTHER'
       BAREQSP   = 'BARRIER EQUIVALENT SPEED'
       BODYTYPE  = 'VEHICLE BODY TYPE'
       CARBUR    = 'CARBURETION'
       CARGOWGT  = 'VEHICLE CARGO WEIGHT'
       CASEID    = 'CASE NUMBER - STRATUM'
       CASENO    = 'CASE SEQUENCE NUMBER'
       CONDTREE  = 'POST COLLISION CONDITION OF TREE OR POLE'
       CURBWGT   = 'VEHICLE CURB WEIGHT'
       DAYRUNLT  = 'DAYLIGHT RUNNING LIGHTS'
       DVEST     = 'ESTIMATED HIGHEST DELTA V'
       DOCTRAJ   = 'DOCUMENTATION OF TRAJECTORY DATA'
       DRIVDIST  = 'DRIVER''S DISTRACTION/INATTENTION TO DRIVING'
       DRINKING  = 'POLICE REPORTED ALCOHOL PRESENCE'
       DRIVE     = 'FRONT/REAR WHEEL DRIVE'
       DRPRES    = 'DRIVER PRESENCE IN VEHICLE'
       DRRACE    = 'DRIVER''S RACE/ETHNIC ORIGIN'
       DRUGS     = 'REPORTED OTHER DRUG'
       DRZIP     = 'DRIVER''S ZIP CODE'
       DVBASIS   = 'BASIS FOR TOTAL DELTA V (HIGHEST)'
       DVCONFID  = 'CONFIDENCE IN RECONSTRUCTION'
       DVLAT     = 'LATERAL COMPONENT OF DELTA V'
       DVLONG    = 'LONGITUDINAL COMPONENT OF DELTA V'
       DVTOTAL   = 'TOTAL DELTA V'
       ENERGY    = 'ENERGY ABSORPTION'
       FOURWHDR  = 'FOUR WHEEL DRIVE'
       FOVERIDE  = 'FRONT OVERRIDE/UNDERRIDE THIS VEHICLE'
       FRTWHLDR  = 'FRONT WHEEL DRIVE'
       FUELCODE  = 'FUEL CODE'
       IMPACTSP  = 'IMPACT SPEED'
       INSPTYPE  = 'TYPE OF VEHICLE INSPECTION'
       LANES     = 'NUMBER OF LANES'
       LGTCOND   = 'LIGHT CONDITIONS'
       MAKE      = 'VEHICLE MAKE'
       MANEUVER  = 'ATTEMPTED AVOIDANCE MANEUVER'
       MCYCLDS   = 'MOTORCYCLE ENGINE DISPLACEMENT'
       MODEL     = 'VEHICLE MODEL'
       MODELYR   = 'VEHICLE MODEL YEAR'
       OCCFORMS  = 'NUMBER OF OCCUPANT FORMS SUBMITTED'
       OCUPANTS  = 'NUMBER OF OCCUPANTS THIS VEHICLE'
       OTBDYTYP  = 'BODY TYPE OF THE OTHER VEHICLE'
       OTVEHWGT  = 'WEIGHT OF THE OTHER VEHICLE'
       PREEVENT  = 'INITIAL CRITICAL (PRECRASH) EVENT'
       PREILOC   = 'PRE-IMPACT LOCATION'
       PREMOVE   = 'PRE-EVENT MOVEMENT PRIOR REC CRIT EVENT'
       PREISTAB  = 'PRE-IMPACT STABILITY'
       PSU       = 'PRIMARY SAMPLING UNIT NUMBER'
       SURCOND   = 'ROADWAY SURFACE CONDITION'
       PROFILE   = 'ROADWAY PROFILE'
       SURTYPE   = 'ROADWAY SURFACE TYPE'
       RELINTER  = 'RELATION TO JUNCTION'
       RESTYPE   = 'RESTRAINT TYPE'
       ROLINDIR  = 'DIRECTION OF INITIAL ROLL'
       ROLINLOC  = 'LOCATION OF ROLLOVER'
       ROLINTYP  = 'ROLLOVER INITIATION TYPE'
       ROLLOBJ   = 'ROLLOVER INITIATION OBJECT CONTACTED'
       ROLLOVER  = 'ROLLOVER'
       ROVERIDE  = 'REAR OVERRIDE/UNDERRIDE THIS VEHICLE'
       ROOF1     = 'ROOF'
       ROOF2     = 'OPTIONAL ROOF 1'
       ROOF3     = 'OPTIONAL ROOF 2'
       SERTR     = 'VIN SERIES TRUCK'
       SPECOTH   = 'OTHER DRUG: SPECIMEN TEST RESULTS'
       SPLIMIT   = 'SPEED LIMIT'
       STRATIF   = 'CASE STRATUM'
       TOWHITCH  = 'TOWED TRAILING UNIT'
       TOWPAR    = 'POLICE REPORTED VEHICLE DISPOSITION'
       TRAFCONT  = 'TRAFFIC CONTROL DEVICE'
       TRCTLFCT  = 'TRAFFIC CONTROL DEVICE FUNCTIONING'
       TRAVELSP  = 'POLICE REPORTED TRAVEL SPEED'
       TRAFFLOW  = 'TRAFFICWAY FLOW'
       TRIPLOC   = 'LOC. ON VEH. WHERE INIT TRIP FORCE APPL'
       VEHTYPE      = 'TYPE OF VEHICLE'
       VAIS      = 'MAXIMUM KNOWN AIS IN THIS VEHICLE'
       VEHNO     = 'VEHICLE NUMBER'
       VEHWGT    = 'VIN VEHICLE WEIGHT'
       VEHUSE    = 'VEHICLE SPECIAL USE'
       VERSION   = 'VERSION NUMBER'
       VIN       = 'VEHICLE IDENTIFICATION NUMBER'
       VINAMOD   = 'VIN MODEL CARS & TRUCKS'
       VINBT     = 'VIN BODY STYLE'
       VINJSER   = 'NUMBER SERIOUSLY INJURED IN THIS VEHICLE'
       VINJURED  = 'NUMBER INJURED IN THIS VEHICLE'
       VINLNGTH  = 'VIN LENGTH'
       VINMAKE   = 'VIN MAKE'
       VINMODYR  = 'VIN MODEL YEAR'
       VINO      = 'VINO'
       VTREAT    = 'MAXIMUM TREATMENT IN THIS VEHICLE'
       WGTCDTR    = 'TRUCK WEIGHT CODE'
       WHLDRWHL  = 'NUMBER WHEELS/NUMBER OF DRIVE WHEELS'

;

 INPUT @  7  CASEKEY4   1.
       @  8  CASEKEY5   1.
       @ 11  CASEKEY1   2.
       @ 13  MODELYR    4.
       @ 17  MAKE       2.
       @ 19  MODEL      3.
       @ 22  BODYTYPE   2.
       @ 24  VIN      $12.  /*COLUMNS 36-40 INTENTIONALLY LEFT BLANK*/
       @ 41  VEHUSE      1.
       @ 42  TOWPAR      1.
       @ 43  TRAVELSP    3.
       @ 46  SPLIMIT     3.
       @ 49  DRINKING    1.
       @ 50  ALCTEST     2.
       @ 52  DRUGS       1.
       @ 53  SPECOTH     1.
       @ 54  DRZIP       5.
       @ 59  DRRACE      1.
       @ 60  RELINTER    1.
       @ 61  TRAFFLOW    1.
       @ 62  LANES       1.
       @ 63  ALIGNMNT    1.
       @ 64  PROFILE     1.
       @ 65  SURTYPE     1.
       @ 66  SURCOND     1.
       @ 67  LGTCOND     1.
       @ 68  WEATHER     1.
       @ 69  TRAFCONT    1.
       @ 70  TRCTLFCT    1.
       @ 71  DRIVDIST    2.
       @ 73  PREMOVE     2.
       @ 75  PREEVENT    2.
       @ 77  MANEUVER    2.
       @ 79  PREISTAB    1.
       @ 80  PREILOC     1.
       @ 81  ACCTYPE     2.
       @ 83  VINO        1.

       /
       @  1  PSU         2.
       @  3  CASENO      3.
       @  6  STRATIF    $1.
       @  7  CASEKEY4    1.
       @  8  CASEKEY5    1.
       @  9  VERSION     $2.
       @ 11  VEHNO       2.   /*ALIAS CASEKEY1 */
       @ 13  DRPRES      1.
       @ 14  OCUPANTS    2.
       @ 16  OCCFORMS    2.
       @ 18  AOPSVEH     1.
       @ 19  BAGDEPFV    1.
       @ 20  BAGDEPOV    1.
       @ 21  CURBWGT     3.
       @ 24  CARGOWGT    3.
       @ 27  ROLLOVER    2.
       @ 29  ROLINTYP    2.
       @ 31  ROLINLOC    1.
       @ 32  ROLLOBJ     2.
       @ 34  TRIPLOC     1.
       @ 35  ROLINDIR    1.
       @ 36  FOVERIDE    1.
       @ 37  ROVERIDE    1.
       @ 38  ANGTHIS     3.
       @ 41  ANGOTHER    3.
       @ 44  TOWHITCH    1.
       @ 45  DOCTRAJ     1.
       @ 46  CONDTREE    1.
       @ 47  DVBASIS     2.
       @ 49  DVTOTAL     3.
       @ 52  DVLONG      4.
       @ 56  DVLAT       4.
       @ 60  ENERGY      4.
       @ 64  IMPACTSP    3.
       @ 67  DVCONFID    1.
       @ 68  BAREQSP     3.
       @ 71  DVEST       1.
       @ 72  INSPTYPE    1.
       @ 73  ACCSEQDV    2.
       @ 75  VTREAT      $1.
       @ 76  VAIS        $1.
       @ 77  VINJSER     $2.
       @ 79  VINJURED    $2.
       @ 81  DRIVE       1.
       @ 82  VINLNGTH    2.
       @ 84  OTVEHWGT    $3.
       @ 87  OTBDYTYP    $2.
       /
       @  1  PSU        2.
       @  3  CASENO     3.
       @  6  STRATIF    $1.
       @ 7  CASEKEY4    1.
       @ 8  CASEKEY5    1.
       @ 9   VERSION    $2.
       @ 11  VEHNO      2.
       @ 13  VINMAKE    $5.
       @ 18  VINAMOD    $3.
       @ 21  SERTR      $3.
       @ 24  VINBT      $2.
       @ 26  ROOF1       1.
       @ 27  ROOF2       1.
       @ 28  ROOF3       1.
       @ 29  ANTILOCK    1.
       @ 30  FRTWHLDR   $1.
       @ 31  FOURWHDR   $1.
       @ 32  RESTYPE    $1.
       @ 33  CARBUR     $1.
       @ 34  FUELCODE   $1.
       @ 35  WGTCDTR     1.
       @ 36  VEHTYPE    $1.
       @ 37  WHLDRWHL    2.
       @ 39  DAYRUNLT    $1.
       @ 40  VEHWGT      4.
       @ 44  MCYCLDS     4.
       @ 48  VINMODYR    4.;



ARRAY ONEGV ALIGNMNT BAGDEPFV BAGDEPOV CONDTREE DOCTRAJ DRINKING DRIVE DRPRES DRRACE
           DRRACE DRUGS DVCONFID DVEST FOVERIDE INSPTYPE LANES
           LGTCOND PREILOC PREISTAB PROFILE RELINTER ROLINDIR
           ROLINLOC ROLINTYP ROVERIDE SPECOTH SURCOND SURTYPE
           TOWHITCH TOWPAR TRAFCONT TRAFFLOW TRCTLFCT TRIPLOC VEHUSE
           WEATHER;

ARRAY GVONE VAIS VTREAT;

ARRAY TWOGV ACCSEQDV ACCTYPE ALCTEST BODYTYPE DRIVDIST DVBASIS
            MAKE MANEUVER OCCFORMS OCUPANTS
            PREEVENT PREMOVE ROLINTYP ROLLOBJ ROLLOVER
            VINLNGTH;

ARRAY GVTWO OTBDYTYP VINJSER VINJURED;

ARRAY THREEGV ANGOTHER ANGTHIS BAREQSP CARGOWGT CURBWGT DVLAT DVLONG
            DVTOTAL IMPACTSP MODEL
            SPLIMIT TRAVELSP;
ARRAY GVTHREE OTVEHWGT;

ARRAY FOURGV ENERGY MODELYR;

ARRAY FIVEGV DRZIP;

DO OVER ONEGV;
   IF ONEGV = 9 THEN ONEGV = .U;
END;

DO OVER GVONE;
   IF GVONE = 9 THEN GVONE = .U;
END;

DO OVER TWOGV;
   IF TWOGV = 99 THEN TWOGV = .U;
END;

DO OVER GVTWO;
   IF GVTWO = 99 THEN GVTWO = .U;
END;

DO OVER THREEGV;
   IF THREEGV = 999 THEN THREEGV = .U;
END;

DO OVER GVTHREE;
   IF GVTHREE = 999 THEN GVTHREE = .U;
END;

DO OVER FOURGV;
   IF FOURGV = 9999 THEN FOURGV = .U;
END;

DO OVER FIVEGV;
   IF FIVEGV = 99999 THEN FIVEGV = .U;
END;


IF (ALCTEST = 95) THEN ALCTEST = .B;
ELSE IF (ALCTEST = 96) THEN ALCTEST =.C;
ELSE IF (ALCTEST = 97) THEN ALCTEST =.D;
ELSE IF (ALCTEST = 98) THEN ALCTEST =.E;

OUTPUT NASSOUT.GV;
END;

/**********************************************************************/
/*                              VE FORM                               */
/**********************************************************************/

ELSE IF (CASEKEY4 = 3 AND CASEKEY5 = 1) THEN DO;

LABEL ACCSEQ1  =  'ACCIDENT EVENT SEQUENCE (HIGHEST)'
      ACCSEQ2  =  'ACCIDENT EVENT SEQUENCE (2ND HIGHEST)'
      ALTVEH   =  'MULTI-STAGE MANUFACTURED/CERT. ALT. VEH.'
      ORIGAVTW =  'ORIGINAL AVERAGE TRACK WIDTH'
      CASEID   =  'CASE NUMBER - STRATUM'
      CASENO   =  'CASE SEQUENCE NUMBER'
      DIRDAMW   =  'DIRECT DAMAGE WIDTH'
      DOCCDC   =  'CDCs DOCUMENTED BUT NOT CODED ON FILE?'
      DOF1     =  'DIRECTION OF FORCE (HIGHEST)'
      DOF2     =  'DIRECTION OF FORCE (2ND HIGHEST)'
      DVC1     =  'CRUSH PROFILE C1 (HIGHEST)'
      DVC2     =  'CRUSH PROFILE C2 (HIGHEST)'
      DVC3     =  'CRUSH PROFILE C3 (HIGHEST)'
      DVC4     =  'CRUSH PROFILE C4 (HIGHEST)'
      DVC5     =  'CRUSH PROFILE C5 (HIGHEST)'
      DVC6     =  'CRUSH PROFILE C6 (HIGHEST)'
      DVD      =  'CRUSH PROFILE D (HIGHEST)'
      DVL      =  'CRUSH PROFILE L (HIGHEST)'
      UNDENDW  =  'UNDEFORMED END WIDTH'
      EXTENT1  =  'DEFORMATION EXTENT (HIGHEST)'
      EXTENT2  =  'DEFORMATION EXTENT (2ND HIGHEST)'
      FUELCAP1 =  'LOCATION OF FUEL TANK-1 FILLER CAP'
      FUELCAP2 =  'LOCATION OF FUEL TANK-2 FILLER CAP'
      FIRE     =  'FIRE OCCURRENCE'
      FIREORIG =  'ORIGIN OF FIRE'
      FUELDAM1 =  'DAMAGE TO FUEL TANK-1'
      FUELDAM2 =  'DAMAGE TO FUEL TANK-2'
      FUELLOC1 =  'LOCATION OF FUEL TANK-1'
      FUELLOC2 =  'LOCATION OF FUEL TANK-2'
      FUELTNK1 =  'TYPE OF FUEL TANK-1'
      FUELTNK2 =  'TYPE OF FUEL TANK-2'
      FUELTYP1 =  'FUEL TYPE-1'
      FUELTYP2 =  'FUEL TYPE-2'
      GAD1     =  'DEFORMATION LOCATION (HIGHEST)'
      GAD2     =  'DEFORMATION LOCATION (2ND HIGHEST)'
      FUELEAK1 =  'LEAKAGE LOCATION OF FUEL SYSTEM-1'
      FUELEAK2 =  'LEAKAGE LOCATION OF FUEL SYSTEM-2'
      FUELGT2 =  'EQUIPPED WITH MORE THAN TWO FUEL TANKS'
      OBJCONT1 =  'OBJECT CONTACTED (HIGHEST)'
      OBJCONT2 =  'OBJECT CONTACTED (2ND HIGHEST)'
      PDOF1    =  'CLOCK DIRECTION FOR PDOF IN DEGREES (HIGHEST CDC)'
      PDOF2    =  'CLOCK DIRECTION FOR PDOF IN DEGREES (2ND HIGHEST CDC)'
      PSU      =  'PRIMARY SAMPLING UNIT NUMBER'
      SDVC1    =  'CRUSH PROFILE C1 (2ND HIGHEST)'
      SDVC2    =  'CRUSH PROFILE C2 (2ND HIGHEST)'
      SDVC3    =  'CRUSH PROFILE C3 (2ND HIGHEST)'
      SDVC4    =  'CRUSH PROFILE C4 (2ND HIGHEST)'
      SDVC5    =  'CRUSH PROFILE C5 (2ND HIGHEST)'
      SDVC6    =  'CRUSH PROFILE C6 (2ND HIGHEST)'
      SDVD     =  'CRUSH PROFILE D (2ND HIGHEST)'
      SDVL     =  'CRUSH PROFILE L (2ND HIGHEST)'
      SHL1     =  'SPECIFIC LONGITUDINAL LOCATION (HIGHEST)'
      SHL2     =  'SPECIFIC LONGITUDINAL LOC. (2ND HIGHEST)'
      STRATIF  =  'CASE STRATUM'
      SVL1     =  'SPECIFIC VERTICAL LOCATION (HIGHEST)'
      SVL2     =  'SPECIFIC VERTICAL LOCATION (2ND HIGHEST)'
      TDD1     =  'TYPE OF DAMAGE DISTRIBUTION (HIGHEST)'
      TDD2     =  'TYPE OF DAMAGE DISTRIBUTION(2ND HIGHEST)'
      TOWRES   =  'RESEARCHER ASSESSMNT VEHICLE DISPOSITION'
      VEHNO    =  'VEHICLE NUMBER'
      VERSION  =  'VERSION NUMBER'
      WHEELBAS =  'ORIGINAL WHEELBASE';

 INPUT @ 11  VEHNO      2.     /* ALIAS CASEKEY1 */
       @ 13  ACCSEQ1    2.
       @ 15  OBJCONT1   2.
       @ 17  DOF1       2.
       @ 19  GAD1      $1.
       @ 20  SHL1      $1.
       @ 21  SVL1      $1.
       @ 22  TDD1      $1.
       @ 23  EXTENT1    2.
       @ 25  ACCSEQ2    2.
       @ 27  OBJCONT2   2.
       @ 29  DOF2       2.
       @ 31  GAD2      $1.
       @ 32  SHL2      $1.
       @ 33  SVL2      $1.
       @ 34  TDD2      $1.
       @ 35  EXTENT2    2.
       @ 37  DVL        3.
       @ 40  DVC1       3.
       @ 43  DVC2       3.
       @ 46  DVC3       3.
       @ 49  DVC4       3.
       @ 52  DVC5       3.
       @ 55  DVC6       3.
       @ 58  DVD        4.
       @ 62  SDVL       3.
       @ 65  SDVC1      3.
       @ 68  SDVC2      3.
       @ 71  SDVC3      3.
       @ 74  SDVC4      3.
       @ 77  SDVC5      3.
       @ 80  SDVC6      3.
       @ 83  SDVD       4.
       @ 87  UNDENDW    3.
       @ 90  DIRDAMW    3.
       @ 93  WHEELBAS   3.
       @ 96  ORIGAVTW   3.
       @ 99  DOCCDC     1.
       @ 100  TOWRES     1.
       @101 ALTVEH     1.
       @102  FIRE       1.
       @103  FIREORIG   1.
       @104  FUELCAP1   1.
       @105  FUELCAP2   1.
       @106  FUELTNK1   1.
       @107  FUELTNK2   1.
       @108  FUELLOC1   1.
       @109  FUELLOC2   1.
       @110  FUELDAM1   1.
       @111  FUELDAM2   1.
       @112  FUELEAK1   1.
       @113  FUELEAK2   1.
       @114  FUELTYP1   2.
       @116  FUELTYP2   2.
       @118  FUELGT2   1.
       @119  PDOF1     3.
       @122  PDOF2     3.
            ;

ARRAY ONEVE ALTVEH FUELCAP1 FUELCAP2 FIRE FIREORIG
            FUELDAM1 FUELDAM2 FUELLOC1 FUELLOC2 FUELTNK1 FUELTNK2
            FUELEAK1 FUELEAK2 FUELGT2 TOWRES;

ARRAY TWOVE DOF1 DOF2 EXTENT1 EXTENT2 FUELTYP1 FUELTYP2
           OBJCONT1 OBJCONT2;

ARRAY THREEVE DIRDAMW ORIGAVTW UNDENDW WHEELBAS PDOF1 PDOF2;

ARRAY FOURVE DVD SDVD;

DO OVER ONEVE;
   IF ONEVE = 9 THEN ONEVE = .U;
END;

DO OVER TWOVE;
   IF TWOVE = 99 THEN TWOVE = .U;
END;

DO OVER THREEVE;
   IF THREEVE = 999 THEN THREEVE = .U;
END;

DO OVER FOURVE;
   IF FOURVE = 9999 THEN FOURVE = .U;
END;

OUTPUT NASSOUT.VE;

END;

/**********************************************************************/
/*                              VI FORM                               */
/**********************************************************************/

ELSE IF (CASEKEY4 = 4 AND CASEKEY5 = 1) THEN DO;

LABEL ADAPTEQ   =  'ADAPTIVE (ASSISTIVE) DRIVING EQUIPMENT'
      BOLSTDEF  =  'KNEE BOLSTER DEFORMED - OCCUPANT CONTACT'
      CASEID    =  'CASE NUMBER - STRATUM'
      CASENO    =  'CASE SEQUENCE NUMBER'
      COLUMTYP  =  'STEERING COLUMN TYPE'
      CDRIR1    =  '1ST DOMINANT CRUSH DIRECTION'
      CDRIR10   =  '10TH DOMINANT CRUSH DIRECTION'
      CDRIR2    =  '2ND DOMINANT CRUSH DIRECTION'
      CDRIR3    =  '3RD DOMINANT CRUSH DIRECTION'
      CDRIR4    =  '4TH DOMINANT CRUSH DIRECTION'
      CDRIR5    =  '5TH DOMINANT CRUSH DIRECTION'
      CDRIR6    =  '6TH DOMINANT CRUSH DIRECTION'
      CDRIR7    =  '7TH DOMINANT CRUSH DIRECTION'
      CDRIR8    =  '8TH DOMINANT CRUSH DIRECTION'
      CDRIR9    =  '9TH DOMINANT CRUSH DIRECTION'
      FAILLF    =  'LF DAMAGE/FAILURE ASSOCIATED W'
      FAILLR    =  'LR DAMAGE/FAILURE - OPENING IN COLLISION'
      FAILRF    =  'RF DAMAGE/FAILURE - OPENING IN COLLISION'
      FAILRR    =  'RR DAMAGE/FAILURE - OPENING IN COLLISION'
      FAILTG    =  'TG DAMAGE/FAILURE - OPENING IN COLLISION'
      GLIMPBL   =  'BL GLAZING DAMAGE FROM IMPACT FORCES'
      GLIMPLF   =  'LF GLAZING DAMAGE FROM IMPACT FORCES'
      GLIMPLR   =  'LR GLAZING DAMAGE FROM IMPACT FORCES'
      GLIMPOTH  =  'OTHER GLAZING DAMAGE FROM IMPACT FORCES'
      GLIMPRF   =  'RF GLAZING DAMAGE FROM IMPACT FORCES'
      GLIMPRR   =  'RR GLAZING DAMAGE FROM IMPACT FORCES'
      GLIMPRUF  =  'ROOF GLAZING DAMAGE FROM IMPACT FORCES'
      GLIMPWS   =  'WS GLAZING DAMAGE FROM IMPACT FORCES'
      GLOCCBL   =  'BL GLAZING DAMAGE FROM OCCUPANT CONTACT'
      GLOCCLF   =  'LF GLAZING DAMAGE FROM OCCUPANT CONTACT'
      GLOCCLR   =  'LR GLAZING DAMAGE FROM OCCUPANT CONTACT'
      GLOCCOTH  =  'OTHER GLAZING DAMAGE FROM OCC. CONTACT'
      GLOCCRF   =  'RF GLAZING DAMAGE FROM OCCUPANT CONTACT'
      GLOCCRR   =  'RR GLAZING DAMAGE FROM OCCUPANT CONTACT'
      GLOCCRUF  =  'ROOF GLAZING DAMAGE FROM OCC. CONTACT'
      GLOCCWS   =  'WS GLAZING DAMAGE FROM OCCUPANT CONTACT'
      GLOVOPEN  =  'DID GLOVE COMPARTMENT DOOR OPEN'
      GLPREBL   =  'BL WINDOW PRECRASH GLAZING STATUS'
      GLPRELF   =  'LF WINDOW PRECRASH GLAZING STATUS'
      GLPRELR   =  'LR WINDOW PRECRASH GLAZING STATUS'
      GLPREOTH  =  'OTHER WINDOW PRECRASH GLAZING STATUS'
      GLPRERF   =  'RF WINDOW PRECRASH GLAZING STATUS'
      GLPRERR   =  'RR WINDOW PRECRASH GLAZING STATUS'
      GLPRERUF  =  'ROOF WINDOW PRECRASH GLAZING STATUS'
      GLPREWS   =  'WS WINDOW PRECRASH GLAZING STATUS'
      GLTYPBL   =  'BL TYPE OF WINDOW/WINDSHIELD GLAZING'
      GLTYPLF   =  'LF TYPE OF WINDOW/WINDSHIELD GLAZING'
      GLTYPLR   =  'LR TYPE OF WINDOW/WINDSHIELD GLAZING'
      GLTYPOTH  =  'OTHER TYPE OF WINDOW/WINDSHIELD GLAZING'
      GLTYPRF   =  'RF TYPE OF WINDOW/WINDSHIELD GLAZING'
      GLTYPRR   =  'RR TYPE OF WINDOW/WINDSHIELD GLAZING'
      GLTYPRUF  =  'ROOF TYPE OF WINDOW/WINDSHIELD GLAZING'
      GLTYPWS   =  'WS TYPE OF WINDOW/WINDSHIELD GLAZING'
      INCOMP1   =  '1ST INTRUDING COMPONENT'
      INCOMP10  =  '10TH INTRUDING COMPONENT'
      INCOMP2   =  '2ND INTRUDING COMPONENT'
      INCOMP3   =  '3RD INTRUDING COMPONENT'
      INCOMP4   =  '4TH INTRUDING COMPONENT'
      INCOMP5   =  '5TH INTRUDING COMPONENT'
      INCOMP6   =  '6TH INTRUDING COMPONENT'
      INCOMP7   =  '7TH INTRUDING COMPONENT'
      INCOMP8   =  '8TH INTRUDING COMPONENT'
      INCOMP9   =  '9TH INTRUDING COMPONENT'
      INLOC1    =  '1ST LOCATION OF INTRUSION'
      INLOC10   =  '10TH LOCATION OF INTRUSION'
      INLOC2    =  '2ND LOCATION OF INTRUSION'
      INLOC3    =  '3RD LOCATION OF INTRUSION'
      INLOC4    =  '4TH LOCATION OF INTRUSION'
      INLOC5    =  '5TH LOCATION OF INTRUSION'
      INLOC6    =  '6TH LOCATION OF INTRUSION'
      INLOC7    =  '7TH LOCATION OF INTRUSION'
      INLOC8    =  '8TH LOCATION OF INTRUSION'
      INLOC9    =  '9TH LOCATION OF INTRUSION'
      INMAG1    =  '1ST MAGNITUDE OF INTRUSION'
      INMAG10   =  '10TH MAGNITUDE OF INTRUSION'
      INMAG2    =  '2ND MAGNITUDE OF INTRUSION'
      INMAG3    =  '3RD MAGNITUDE OF INTRUSION'
      INMAG4    =  '4TH MAGNITUDE OF INTRUSION'
      INMAG5    =  '5TH MAGNITUDE OF INTRUSION'
      INMAG6    =  '6TH MAGNITUDE OF INTRUSION'
      INMAG7    =  '7TH MAGNITUDE OF INTRUSION'
      INMAG8    =  '8TH MAGNITUDE OF INTRUSION'
      INMAG9    =  '9TH MAGNITUDE OF INTRUSION'
      ODOMETER  =  'ODOMETER READING'
      OPENLF    =  'LF DOOR, TAILGATE OR HATCH OPENING'
      OPENLR    =  'LR DOOR, TAILGATE OR HATCH OPENING'
      OPENRF    =  'RF DOOR, TAILGATE OR HATCH OPENING'
      OPENRR    =  'RR DOOR, TAILGATE OR HATCH OPENING'
      OPENTG    =  'TG DOOR, TAILGATE OR HATCH OPENING'
      PANELDAM  =  'INSTRUMENT PANEL DAMAGE - OCC. CONTACT'
      PASINTEG  =  'PASSENGER COMPARTMENT INTEGRITY'
      PSU       =  'PRIMARY SAMPLING UNIT NUMBER'
      RDEFLOC   =  'LOCATION STEERING RIM/SPOKE DEFORMATION'
      RIMDEF    =  'STEERING RIM/SPOKE DEFORMATION'
      STRATIF   =  'CASE STRATUM'
      COLMTELE   =  'TELESCOPING STEERING COLUMN ADJUSTMENT'
      COLMTILT   =  'TILT STEERING COLUMN ADJUSTMENT'
      BOLSTYPE   =  'TYPE OF KNEE BOLSTER COVERING'
      VEHNO     =  'VEHICLE NUMBER'
      VERSION   =  'VERSION NUMBER';


                                /* RECORD #1    */
 INPUT                          /* OVERWRITE RECORD TYPE='42' ON FIRST*/
                                /* VI RECORD                          */
       @ 11  VEHNO       2.     /* ALIAS CASEKEY1 */
       @ 13  PASINTEG    2.
       @ 15  OPENLF      1.
       @ 16  OPENRF      1.
       @ 17  OPENLR      1.
       @ 18  OPENRR      1.
       @ 19  OPENTG      1.
       @ 20  FAILLF      1.
       @ 21  FAILRF      1.
       @ 22  FAILLR      1.
       @ 23  FAILRR      1.
       @ 24  FAILTG      1.
       @ 25  GLTYPWS     1.
       @ 26  GLTYPLF     1.
       @ 27  GLTYPRF     1.
       @ 28  GLTYPLR     1.
       @ 29  GLTYPRR     1.
       @ 30  GLTYPBL     1.
       @ 31  GLTYPRUF    1.
       @ 32  GLTYPOTH    1.
       @ 33  GLPREWS     1.
       @ 34  GLPRELF     1.
       @ 35  GLPRERF     1.
       @ 36  GLPRELR     1.
       @ 37  GLPRERR     1.
       @ 38  GLPREBL     1.
       @ 39  GLPRERUF    1.
       @ 40  GLPREOTH    1.
       @ 41  GLIMPWS     1.
       @ 42  GLIMPLF     1.
       @ 43  GLIMPRF     1.
       @ 44  GLIMPLR     1.
       @ 45  GLIMPRR     1.
       @ 46  GLIMPBL     1.
       @ 47  GLIMPRUF    1.
       @ 48  GLIMPOTH    1.
       @ 49  GLOCCWS     1.
       @ 50  GLOCCLF     1.
       @ 51  GLOCCRF     1.
       @ 52  GLOCCLR     1.
       @ 53  GLOCCRR     1.
       @ 54  GLOCCBL     1.
       @ 55  GLOCCRUF    1.
       @ 56  GLOCCOTH    1.
       /
       @ 1   PSU         2.                           /* RECORD #2    */
       @ 3   CASENO      3.
       @ 6   STRATIF    $1.
       @ 7   CASEKEY4    1.
       @ 8   CASEKEY5    1.
       @ 9   VERSION     $2.
       @ 11  VEHNO       2.      /* ALIAS VEHNO */
       @ 13  INLOC1      2.
       @ 15  INCOMP1     2.
       @ 17  INMAG1      1.
       @ 18  CDRIR1      1.
       @ 19  INLOC2      2.
       @ 21  INCOMP2     2.
       @ 23  INMAG2      1.
       @ 24  CDRIR2      1.
       @ 25  INLOC3      2.
       @ 27  INCOMP3     2.
       @ 29  INMAG3      1.
       @ 30  CDRIR3      1.
       @ 31  INLOC4      2.
       @ 33  INCOMP4     2.
       @ 35  INMAG4      1.
       @ 36  CDRIR4      1.
       @ 37  INLOC5      2.
       @ 39  INCOMP5     2.
       @ 41  INMAG5      1.
       @ 42  CDRIR5      1.
       @ 43  INLOC6      2.
       @ 45  INCOMP6     2.
       @ 47  INMAG6      1.
       @ 48  CDRIR6      1.
       @ 49  INLOC7      2.
       @ 51  INCOMP7     2.
       @ 53  INMAG7      1.
       @ 54  CDRIR7      1.
       @ 55  INLOC8      2.
       @ 57  INCOMP8     2.
       @ 59  INMAG8      1.
       @ 60  CDRIR8      1.
       @ 61  INLOC9      2.
       @ 63  INCOMP9     2.
       @ 65  INMAG9      1.
       @ 66  CDRIR9      1.
       @ 67  INLOC10     2.
       @ 69  INCOMP10    2.
       @ 71  INMAG10     1.
       @ 72  CDRIR10     1.
       @ 73  COLUMTYP    1.    /*COLUMNS 74 - 84 LEFT INTENTIONALLY BLANK*/
       @ 85  COLMTILT    1.
       @ 86  COLMTELE    1.
       @ 87  RIMDEF      2.
       @ 89  RDEFLOC     2.
       @ 91  ODOMETER    3.
       @ 94  PANELDAM    1.
       @ 95  BOLSTYPE    1.
       @ 96  BOLSTDEF    1.
       @ 97  GLOVOPEN    1.
       @ 98  ADAPTEQ     1.
                  ;

ARRAY ONEVI ADAPTEQ BOLSTDEF BOLSTYPE CDRIR1-CDRIR9 CDRIR10  COLMTELE
           COLMTILT COLUMTYP
           FAILLF FAILLR FAILRF FAILRR FAILTG
           GLIMPBL GLIMPLF GLIMPLR GLIMPOTH GLIMPRF GLIMPRR GLIMPRUF
           GLIMPWS
           GLOCCBL GLOCCLF GLOCCLR GLOCCOTH GLOCCRF GLOCCRR GLOCCRUF
           GLOCCWS
           GLOVOPEN
           GLPREBL GLPRELF GLPRELR GLPREOTH GLPRERF GLPRERR GLPRERUF
           GLPREWS
           GLTYPBL GLTYPLF GLTYPLR GLTYPOTH GLTYPRF GLTYPRR GLTYPRUF
           GLTYPWS
           INMAG1-INMAG9 INMAG10
           OPENLF OPENLR OPENRF OPENRR OPENTG
           PANELDAM;

ARRAY TWOVI INCOMP1-INCOMP9 INCOMP10 INLOC1-INLOC9 INLOC10
           PASINTEG RDEFLOC RIMDEF;

ARRAY THREEVI ODOMETER;

DO OVER ONEVI;
   IF ONEVI = 9 THEN ONEVI = .U;
END;

DO OVER TWOVI;
   IF TWOVI = 99 THEN TWOVI = .U;
END;

DO OVER THREEVI;
   IF THREEVI = 999 THEN THREEVI = .U;
END;

OUTPUT NASSOUT.VI;

END;

/**********************************************************************/
/*                              OA FORM                               */
/**********************************************************************/

ELSE IF (CASEKEY4 = 5 AND CASEKEY5 = 1) THEN DO;

LABEL ABELTAVL  = 'AUTOMATIC BELT SYSTEM AVAILABILITY/FUNC'
      ABELTUSE  = 'AUTOMATIC BELT (PASSIVE) SYSTEM USE'
      ABELTYPE  = 'AUTOMATIC (PASSIVE) BELT SYSTEM TYPE'
      ABLTPROP  = 'PROPER USE OF AUTO (PASSIVE) BELT SYSTEM'
      ABLTFAIL  = 'AUTOMATIC (PASSIVE) BELT SYSTEM FAILURE'
      AGE       =  'AGE OF OCCUPANT'
      BAGAVAIL  =  'AIR BAG SYSTEM AVAILABILITY'
      BAGDEPLY  =  'AIR BAG SYSTEM DEPLOYED'
      BAGDAMAG    =  'WAS THERE DAMAGE TO THE AIR BAG'
      BAGFAIL   =  'AIR BAG SYSTEM FAILURE'
      BAGTETHR   =  'WAS THE AIR BAG TETHERED'
      BICARB    =  'ARTERIAL BLOOD GASES (ABG) HC03'
      BLOOD     =  'WAS THE OCCUPANT GIVEN BLOOD?'
      BELTANCH    =  'SHOULDER BELT UPPER ANCHORAGE ADJUSTMENT'
      CASEID    =  'CASE NUMBER - STRATUM'
      CASENO    =  'CASE SEQUENCE NUMBER'
      CAUSE1    =  '1ST MEDICALLY REPORTED CAUSE OF DEATH'
      CAUSE2    =  '2ND MEDICALLY REPORTED CAUSE OF DEATH'
      CAUSE3    =  '3RD MEDICALLY REPORTED CAUSE OF DEATH'
      BAGCDC   =  'CDC FOR AIR BAG DEPLOYMENT IMPACT'
      CHHARNES  =  'CHILD SAFETY SEAT HARNESS USAGE'
      CHMAKE    =  'CHILD SAFETY SEAT MAKE/MODEL'
      CHORIENT  =  'CHILD SAFETY SEAT ORIENTATION'
      CHSHIELD  =  'CHILD SAFETY SEAT SHIELD USAGE'
      CHTETHER  =  'CHILD SAFETY SEAT TETHER USAGE'
      CHTYPE    =  'TYPE OF CHILD SAFETY SEAT'
      BAGCONOT  =  'AIR BAG CONTACTED BY ANOTHER OCCUPANT'
      DEATH     =  'TIME TO DEATH'
      BAGEVENT   =  'AIR BAG DEPLOYMENT ACCIDENT EVENT SEQUENCE NUMBER'
      DVBAG  =  'LONGITUDINAL COMPONENT OF DELTA V FOR AIR BAG'
      EJCTAREA  =  'EJECTION AREA'
      EJCTMED   =  'EJECTION MEDIUM'
      EJECTION  =  'EJECTION'
      ENTRAP    =  'ENTRAPMENT'
      BAGFLDAM   =  'WERE AIR BAG MODULE COVER FLAPS DAMAGED'
      BAGFLOPN   =  'DID AIR BAG MODULE COVER FLAPS OPEN AT DESG TEAR PTS'
      GLASGOW   =  'GLASGOW COMA SCALE (GCS) SCORE'
      HEADREST  =  'HEAD RESTRAINT TYPE/DAMAGE BY OCCUPANT'
      HEIGHT    =  'HEIGHT OF OCCUPANT'
      HOSPSTAY  =  'HOSPITAL STAY'
      INJNUM    =  'NUMBER RECORDED INJURIES THIS OCCUPANT'
      INJSEV    =  'INJURY SEVERITY (POLICE RATING)'
      ISS       =  'INJURY SEVERITY SCORE'
      BAGMAINT   =  'PRIOR MAINTENANCE/SERVICE ON AIR BAG'
      MAIS      =  'MAXIMUM KNOWN OCCUPANT AIS'
      MANAVAIL  =  'MANUAL BELT SYSTEM AVAILABILITY'
      MANFAIL   =  'MANUAL BELT FAILURE MODE DURING ACCIDENT'
      MANPROPR  =  'PROPER USE OF MANUAL BELTS'
      MANUSE    =  'MANUAL BELT SYSTEM USE'
      MEDFACIL  =  'TYPE MEDICAL FACILITY INITIAL TREATMENT'
      MEDSTA    =  'MEDIUM STATUS (PRIOR TO IMPACT)'
      EYEWEAR    =  'WAS THE OCCUPANT WEARING EYE-WEAR'
      OCCMOBIL    =  'OCCUPANT MOBILITY'
      OCCNO     =  'OCCUPANT NUMBER'
      BAGAVOTH  =  'OTHER FRONTAL AIR BAG AVAILABILITY/FUNCTION'
      BAGDEPOT  =  'OTHER AIR BAG SYSTEM DEPLOYMENT'
      BAGAVRPT    =  'POLICE REPORTED AIRBAG AVAILABILITY/FUNCTION'
      /*RABCLASS  = 'REDESIGNED AIR BAG CLASS'*/
      PARUSE    =  'POLICE REPORTED RESTRAINT USE'
      BELTSOU  =  'PRIMARY SOURCE OF BELT USE DETERMINATION'
      POSTURE   =  'OCCUPANT''S POSTURE'
      PREVACC  =  'HAD VEHICLE BEEN IN PREVIOUS ACCIDENTS'
      PSU       =  'PRIMARY SAMPLING UNIT NUMBER'
      ROLE      =  'OCCUPANT''S ROLE'
      SEATPERF  =  'SEAT PERFORMANCE (THIS POSITION)'
      SEATPOS   =  'OCCUPANT''S SEAT POSITION'
      SEATTYPE  =  'SEAT TYPE (THIS OCCUPANT POSITION)'
      SEX       =  'OCCUPANT''S SEX'
      BAGDAMSO    =  'SOURCE OF AIR BAG DAMAGE'
      STBACINC  =  'SEAT BACK INCLINE PRIOR AND POST IMPACT'
      STORIENT  =  'SEAT ORIENTATION (THIS OCCUPANT POS.)'
      STRATIF   =  'CASE STRATUM'
      SEATRACK  =  'SEAT TRACK ADJUSTED POSITION PRIOR TO IMPACT'
      TREATMNT  =  'TREATMENT - MORTALITY'
      BAGTYPE   =  'TYPE OF AIR BAG'
      VEHNO     =  'VEHICLE NUMBER'
      BAGVENTS   =  'DID THE AIR BAG HAVE VENT PORTS'
      VERSION   =  'VERSION NUMBER'
      WEIGHT    =  'OCCUPANT''S WEIGHT'
      WORKDAYS  =  'WORKING DAYS LOST'
;

 INPUT @ 11  VEHNO      2.     /* ALIAS CASEKEY1 */
       @ 13  OCCNO      2.     /* ALIAS CASEKEY2 */
       @ 15  AGE        2.
       @ 17  SEX        1.
       @ 18  HEIGHT     3.
       @ 21  WEIGHT     3.
       @ 24  ROLE       1.
       @ 25  SEATPOS    2.
       @ 27  POSTURE    2.
       @ 29  EJECTION   1.
       @ 30  EJCTAREA   1.
       @ 31  EJCTMED    1.
       @ 32  MEDSTA     1.
       @ 33  ENTRAP     1.
       @ 34  OCCMOBIL     1.
       @ 35  MANAVAIL   1.
       @ 36  MANUSE     2.
       @ 38  MANPROPR   1.
       @ 39  MANFAIL    1.
       @ 40  BELTANCH   1.
       @ 41  ABELTAVL   1.
       @ 42  ABELTUSE   1.
       @ 43  ABELTYPE   1.
       @ 44  ABLTPROP   1.
       @ 45  ABLTFAIL   1.
       @ 46  PARUSE     1.
       @ 47  BAGAVRPT     1.
       @ 48  BAGAVAIL   1.
       @ 49  BAGDEPLY   1.
       @ 50  BAGAVOTH   1.
       @ 51  BAGDEPOT   1.
       @ 52  BAGFAIL    1.
       @ 53  PREVACC   1.
       @ 54  BAGTYPE     1.
       @ 55  BAGMAINT    1.
       @ 56  BAGEVENT    2.
       @ 58  BAGCDC    1.
       @ 59  DVBAG   4.
       @ 63  BAGFLOPN    1.
       @ 64  BAGFLDAM    1.
       @ 65  BAGDAMAG     2.
       @ 67  BAGDAMSO     2.
       @ 69  BAGTETHR    1.
       @ 70  BAGVENTS    1.
       @ 71  BAGCONOT    1.
       @ 72  EYEWEAR     1.
       @ 73  HEADREST   1.
       @ 74  SEATTYPE   2.
       @ 76  STORIENT   1.
       @ 77  SEATRACK   1.
       @ 78  STBACINC   2.
       @ 80  SEATPERF   1.
       @ 81  CHMAKE     3.
       @ 84  CHTYPE     1.
       @ 85  CHORIENT   2.
       @ 87  CHHARNES   2.
       @ 89  CHSHIELD   2.
       @ 91  CHTETHER   2.
       @ 93  INJSEV     1.
       @ 94  TREATMNT   1.
       @ 95 MEDFACIL   1.
       @ 96  HOSPSTAY   2.
       @ 98  WORKDAYS   2.
       @ 100  DEATH      2.
       @ 102  CAUSE1     2.
       @ 104 CAUSE2     2.
       @ 106 CAUSE3     2.
       @ 108 INJNUM     2.
       @ 110 GLASGOW    2.
       @ 112 BLOOD      1.
       @ 113 BICARB     2.
       @ 115 BELTSOU   1.
       /*@ 115 RABCLASS   1.*/
       @ 116 MAIS       1.
       @ 117 ISS        2.
                  ;

ARRAY ONEOA ABELTAVL ABELTYPE ABELTUSE ABLTFAIL ABLTPROP BAGAVAIL BAGAVOTH
           BAGAVRPT BAGCDC BAGCONOT BAGDEPLY BAGDEPOT BAGFAIL BAGFLDAM
           BAGFLOPN BAGMAINT BAGTETHR BAGTYPE BAGVENTS BELTANCH BELTSOU
           BLOOD CHTYPE EJCTAREA EJCTMED EJECTION ENTRAP EYEWEAR HEADREST
           INJSEV MAIS MANAVAIL MANFAIL MANPROPR MEDFACIL MEDSTA
           OCCMOBIL PARUSE PREVACC ROLE SEATPERF SEATRACK
           SEX STORIENT TREATMNT;

ARRAY TWOOA AGE BAGDAMAG BAGDAMSO BAGEVENT BICARB CAUSE1 CAUSE2 CAUSE3 CHHARNES
           CHORIENT CHSHIELD
           CHTETHER DEATH GLASGOW HOSPSTAY INJNUM ISS MANUSE POSTURE
           SEATPOS SEATTYPE STBACINC WORKDAYS;

ARRAY THREEOA CHMAKE DVBAG HEIGHT WEIGHT;


DO OVER ONEOA;
   IF ONEOA = 9 THEN ONEOA = .U;
END;

DO OVER TWOOA;
   IF TWOOA = 99 THEN TWOOA = .U;
END;

DO OVER THREEOA;
   IF THREEOA = 999 THEN THREEOA = .U;
END;


OUTPUT NASSOUT.OA;

END;

/**********************************************************************/
/*                              OI FORM                               */
/**********************************************************************/

ELSE IF (CASEKEY4 = 6 AND CASEKEY5 = 1) THEN DO;

LABEL AIS      =  'A.I.S. SEVERITY'
      ASPECT90 =  'ASPECT90'
      BODYREG  =  'BODY REGION'
      CASEID   =  'CASE NUMBER - STRATUM'
      CASENO   =  'CASE SEQUENCE NUMBER'
      DIRINJ   =  'DIRECT/INDIRECT INJURY'
      INJLEVEL =  'INJURY LEVEL'
      INJNO    =  'INJURY NUMBER'
      INJSOU   =  'INJURY SOURCE'
      INTRUNO  =  'OCCUPANT AREA INTRUSION NO.'
      LESION   =  'LESION (A.I.S. - O.I.C.)'
      OCCNO    =  'OCCUPANT NUMBER'
      PSU      =  'PRIMARY SAMPLING UNIT NUMBER'
      REGION90 =  'BODY REGION (O.I.C. - A.I.S.)'
      SOUCON   =  'INJURY SOURCE CONFIDENCE LEVEL'
      SOUDAT   =  'SOURCE OF INJURY DATA'
      STRATIF  =  'CASE STRATUM'
      STRUSPEC =  'SPECIFIC ANATOMIC STRUCTURE'
      STRUTYPE =  'TYPE OF ANATOMIC STRUCTURE'
      SYSORG   =  'SYSTEM/ORGAN (A.I.S. - O.I.C.)'
      VEHNO    =  'VEHICLE NUMBER'
      VERSION  =  'VERSION NUMBER';

 INPUT @ 11  VEHNO      2.     /* ALIAS CASEKEY1 */
       @ 13  OCCNO      2.     /* ALIAS CASEKEY2 */
       @ 15  INJNO      2.     /* ALIAS CASEKEY3 */
       @ 17  SOUDAT     1.
       @ 18  REGION90   1.
       @ 19  STRUTYPE   1.
       @ 20  STRUSPEC   2.
       @ 22  INJLEVEL   2.
       @ 24  AIS        1.
       @ 25  ASPECT90   1.
       @ 26  INJSOU     3.
       @ 29  SOUCON     1.
       @ 30  DIRINJ     1.
       @ 31  INTRUNO    2.
       @ 33  BODYREG    $1.
       @ 34  LESION     $1.
       @ 35  SYSORG     $1.
                  ;

ARRAY ONEOI ASPECT90 SOUCON;

ARRAY TWOOI INTRUNO;

ARRAY THREEOI INJSOU;

DO OVER ONEOI;
   IF ONEOI = 9 THEN ONEOI = .U;
END;

DO OVER TWOOI;
   IF TWOOI = 99 THEN TWOOI = .U;
END;

DO OVER THREEOI;
   IF THREEOI = 999 THEN THREEOI = .U;
END;

OUTPUT NASSOUT.OI;

END;


/**********************************************************************/
/*                   TYPE ACCIDENT FORM                               */
/**********************************************************************/

ELSE IF (CASEKEY4 = 6 AND CASEKEY5 = 6) THEN DO;

LABEL CASEID   =  'CASE NUMBER - STRATUM'
      CASENO   =  'CASE SEQUENCE NUMBER'
      LINENO   =  'LINE NUMBER'
      PSU      =  'PRIMARY SAMPLING UNIT NUMBER'
      STRATIF   =  'CASE STRATUM'
      TEXT66     =  'SUMMARY TEXT'
      VERSION  =  'VERSION NUMBER';

 INPUT @ 11  LINENO    2. /*ALIAS CASEKEY3*/
       @ 13  TEXT66    $80.
                   ;

OUTPUT NASSOUT.TYP_ACC;

END;

/**********************************************************************/
/*                   ACCIDENT DESCRIPTION FORM                        */
/**********************************************************************/

ELSE IF (CASEKEY4 = 7 AND CASEKEY5 = 1) THEN DO;

LABEL CASEID   =  'CASE NUMBER - STRATUM'
      CASENO   =  'CASE SEQUENCE NUMBER'
      LINENO   =  'LINE NUMBER'
      PSU      =  'PRIMARY SAMPLING UNIT NUMBER'
      STRATIF   =  'CASE STRATUM'
      TEXT71     =  'SUMMARY TEXT'
      VERSION  =  'VERSION NUMBER';

 INPUT @ 11    LINENO  2.  /*ALIAS CASEKEY3*/
       @ 13    TEXT71     $80.
                   ;

OUTPUT NASSOUT.ACC_DESC;

END;

/**********************************************************************/
/*                   VEHICLE PROFILE FORM                             */
/**********************************************************************/

ELSE IF (CASEKEY4 = 8 AND CASEKEY5 = 1) THEN DO;

LABEL CASEID   =  'CASE NUMBER - STRATUM'
      CASENO   =  'CASE SEQUENCE NUMBER'
      LINENO   =  'LINE NUMBER'
      PSU      =  'PRIMARY SAMPLING UNIT NUMBER'
      STRATIF   =  'CASE STRATUM'
      TEXT81     =  'SUMMARY TEXT'
      VERSION  =  'VERSION NUMBER';

 INPUT @ 11    LINENO   2.  /*ALIAS CASEKEY3*/
       @ 13    TEXT81   $80.
                   ;

OUTPUT NASSOUT.VEH_PRO;

END;

/**********************************************************************/
/*                   PERSONAL PROFILE FORM                            */
/**********************************************************************/

ELSE IF (CASEKEY4 = 9 AND CASEKEY5 = 1) THEN DO;

LABEL CASEID   =  'CASE NUMBER - STRATUM'
      CASENO   =  'CASE SEQUENCE NUMBER'
      LINENO   =  'LINE NUMBER'
      PSU      =  'PRIMARY SAMPLING UNIT NUMBER'
      STRATIF   =  'CASE STRATUM'
      TEXT91   =  'SUMMARY TEXT'
      VERSION  =  'VERSION NUMBER';

 INPUT @ 11    LINENO   2.  /*ALIAS CASEKEY3*/
       @ 13    TEXT91     $80.
                   ;

OUTPUT NASSOUT.PERS_PRO;

END;

run;
